@@ -58,21 +58,26 @@ class EasySpreadsheet():
     def select(self):
         return self.table
     
-    def push(self):
-        
+    def push(self, cell_indexes=[]):
+        cell_indexes = set(cell_indexes)
+
         cell_list = []
         
         for index, row in enumerate(json.loads(json.dumps(self.table.to_dict(orient='records'), ensure_ascii=False, cls=NumpyEncoder))):
             values = self._make_sheet_row(row.values())
 
             for value_index, value in enumerate(values):
+                if cell_indexes and (index + 1, value_index + 1) not in cell_indexes:
+                    continue
+
                 cell = gspread.models.Cell(index + 1, value_index + 1)
                 cell.value = value
                 cell_list.append(cell)
 
         self._cloudsheet.clear()
         self._cloudsheet.update_cells(cell_list)
-        
+
+
     def format(self, start_column, start_index, end_column, end_index, cell_format):
         
         range_name = self._spread_order[start_column] + str(start_index + 1) + ":" + \
@@ -119,9 +124,6 @@ class EasySpreadsheet():
 
         self.table = pd.DataFrame(rows)
         
-
-
-
     def _parse(self, value):
         if type(value) is list or type(value) is dict:
             v = value
